@@ -221,6 +221,7 @@ class EdgeFunction(
         max_record_age: typing.Optional[aws_cdk.core.Duration] = None,
         on_failure: typing.Optional[aws_cdk.aws_lambda.IEventSourceDlq] = None,
         parallelization_factor: typing.Optional[jsii.Number] = None,
+        report_batch_item_failures: typing.Optional[builtins.bool] = None,
         retry_attempts: typing.Optional[jsii.Number] = None,
         source_access_configurations: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.SourceAccessConfiguration]] = None,
         starting_position: typing.Optional[aws_cdk.aws_lambda.StartingPosition] = None,
@@ -239,6 +240,7 @@ class EdgeFunction(
         :param max_record_age: The maximum age of a record that Lambda sends to a function for processing. Valid Range: - Minimum value of 60 seconds - Maximum value of 7 days Default: - infinite or until the record expires.
         :param on_failure: An Amazon SQS queue or Amazon SNS topic destination for discarded records. Default: discarded records are ignored
         :param parallelization_factor: The number of batches to process from each shard concurrently. Valid Range: - Minimum value of 1 - Maximum value of 10 Default: 1
+        :param report_batch_item_failures: Allow functions to return partially successful responses for a batch of records. Default: false
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Set to ``undefined`` if you want lambda to keep retrying infinitely or until the record expires. Valid Range: - Minimum value of 0 - Maximum value of 10000 Default: - infinite or until the record expires.
         :param source_access_configurations: Specific settings like the authentication protocol or the VPC components to secure access to your event source. Default: - none
         :param starting_position: The position in the DynamoDB, Kinesis or MSK stream where AWS Lambda should start reading. Default: - Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
@@ -255,6 +257,7 @@ class EdgeFunction(
             max_record_age=max_record_age,
             on_failure=on_failure,
             parallelization_factor=parallelization_factor,
+            report_batch_item_failures=report_batch_item_failures,
             retry_attempts=retry_attempts,
             source_access_configurations=source_access_configurations,
             starting_position=starting_position,
@@ -348,6 +351,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[aws_cdk.core.Duration] = None,
         region: typing.Optional[builtins.str] = None,
@@ -361,7 +365,8 @@ class EdgeFunction(
         :param metric_name: -
         :param account: Account which this metric comes from. Default: - Deployment account.
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
         :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
@@ -372,6 +377,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
@@ -388,6 +394,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[aws_cdk.core.Duration] = None,
         region: typing.Optional[builtins.str] = None,
@@ -403,7 +410,8 @@ class EdgeFunction(
 
         :param account: Account which this metric comes from. Default: - Deployment account.
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
         :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
@@ -414,6 +422,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
@@ -430,6 +439,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[aws_cdk.core.Duration] = None,
         region: typing.Optional[builtins.str] = None,
@@ -442,7 +452,8 @@ class EdgeFunction(
 
         :param account: Account which this metric comes from. Default: - Deployment account.
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
         :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
@@ -453,6 +464,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
@@ -469,6 +481,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[aws_cdk.core.Duration] = None,
         region: typing.Optional[builtins.str] = None,
@@ -484,7 +497,8 @@ class EdgeFunction(
 
         :param account: Account which this metric comes from. Default: - Deployment account.
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
         :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
@@ -495,6 +509,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
@@ -511,6 +526,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[aws_cdk.core.Duration] = None,
         region: typing.Optional[builtins.str] = None,
@@ -526,7 +542,8 @@ class EdgeFunction(
 
         :param account: Account which this metric comes from. Default: - Deployment account.
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
         :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
@@ -537,6 +554,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
